@@ -24,19 +24,17 @@ from collections import namedtuple
 from math import ceil, floor
 
 from PyQt5.QtCore import (Qt, QSize, pyqtSignal)
-from PyQt5.QtGui import QPainter, QFont, QColor, QPixmap, QFontMetrics, QKeyEvent, QStatusTipEvent, QMouseEvent, \
-	QFontInfo
+from PyQt5.QtGui import QPainter, QFont, QColor, QPixmap, QFontMetrics, QKeyEvent, QStatusTipEvent, QMouseEvent
 from PyQt5.QtWidgets import QWidget, QApplication, QMenu, QSizePolicy, QAction, QInputDialog
 
-from pre_workbench import configs
+from pre_workbench.bbuf_parsing import apply_grammar_on_bbuf
+from pre_workbench import configs, guihelper
 from pre_workbench.algo.range import Range
 from pre_workbench.configs import SettingsSection
 from pre_workbench.guihelper import setClipboardText, showWidgetDlg, getClipboardText
 from pre_workbench.app import GlobalEvents
 from pre_workbench.controls.hexview_selheur import SelectionHelpers
 from pre_workbench.objects import ByteBuffer, parseHexFromClipboard, BidiByteBuffer
-from pre_workbench.structinfo.exceptions import parse_exception
-from pre_workbench.structinfo.parsecontext import BytebufferAnnotatingParseContext
 from pre_workbench.util import PerfTimer
 
 group = SettingsSection('HexView2', 'Hex Editor', 'address', 'Address Styles')
@@ -75,20 +73,12 @@ class HexView2(QWidget):
 	parseResultsUpdated = pyqtSignal(list)
 	selectionChanged = pyqtSignal(object)
 
-	userStyles = [
-		("R", "Red", {"color": "#aa0000"}),
-		("G", "Green", {"color": "#00aa00"}),
-		("Y", "Yellow", {"color": "#aaaa00"}),
-		("L", "Blue", {"color": "#0000aa"}),
-		("M", "Magenta", {"color": "#aa00aa"}),
-		("T", "Turqoise", {"color": "#00aaaa"}),
-	]
-
 	def __init__(self, byteBuffer=None, annotationSetDefaultName="", options=dict(), optionsConfigKey="HexViewParams", project=None, formatInfoContainer=None):
 		super().__init__()
 		self.project = project
 		self.formatInfoContainer = formatInfoContainer
 		if self.formatInfoContainer: self.formatInfoContainer.updated.connect(self._formatInfoUpdated)
+		logging.debug("HexView - formatInfoContainer = %r", self.formatInfoContainer)
 		self.annotationSetDefaultName = annotationSetDefaultName
 		self.annotationSetName = None
 		self.buffers = list()
@@ -177,9 +167,9 @@ class HexView2(QWidget):
 		ctxMenu.exec(self.mapToGlobal(point))
 
 	def _buildSelectionContextMenu(self, ctx):
-		ctx.addAction(QAction("Copy selection hex\tCtrl-C", ctx, triggered=lambda: self.copySelection(), shortcut="Ctrl+C"))
-		ctx.addAction("Copy selection C Array", lambda: self.copySelection((", ", "0x%02X")))
-		ctx.addAction("Copy selection hexdump\tCtrl-Shift-C", lambda: self.copySelection("hexdump"))
+		ctx.addAction(QAction("Copy Selection as Hex\tCtrl-C", ctx, triggered=lambda: self.copySelection(), shortcut="Ctrl+C"))
+		ctx.addAction("Copy Selection C Array", lambda: self.copySelection((", ", "0x%02X")))
+		ctx.addAction("Copy Selection Hexdump\tCtrl-Shift-C", lambda: self.copySelection("hexdump"))
 		#ctx.addAction("Copy selected annotations", lambda: self.copySelection("hexdump"))
 		ctx.addSeparator()
 		#ctx.addAction("Selection %d-%d (%d bytes)"%(self.selStart,self.selEnd,self.selLength()))
@@ -188,32 +178,32 @@ class HexView2(QWidget):
 			match = next(
 				self.buffers[self.selBuffer].matchRanges(start=self.selFirst(), end=self.selLast()+1, doesntHaveMetaKey='_sdef_ref'))
 
-			ctx.addAction("&Delete selected style\tX", lambda: self.deleteSelectedStyle())
+			ctx.addAction("&Delete Selected Style\tX", lambda: self.deleteSelectedStyle())
 
 			ctx.addSeparator()
 		except StopIteration:
 			pass
-		for key, name, style in HexView2.userStyles:
-			ctx.addAction(name+"\t"+key, lambda: self.styleSelection(**style))
+		for key, name, style in guihelper.getHighlightStyles():
+			ctx.addAction(name+"\t"+key, lambda style=style: self.styleSelection(**style))
 		ctx.addSeparator()
 		ctx.addAction("&Start Section...", lambda: self.setSectionSelection())
 		ctx.addSeparator()
 
 		if self.selLength() > 1:
 			if self.project:
-				menu = ctx.addMenu( "Apply annotation set for selection")
+				menu = ctx.addMenu( "Apply Annotation Set For Selection")
 				for name in self.project.getAnnotationSetNames():
 					#TODO implement this
 					menu.addAction(name, lambda name=name: print(name))
 		else:
 			if self.project:
-				menu = ctx.addMenu("Load annotation set")
+				menu = ctx.addMenu("Load Annotation Set")
 				for name in self.project.getAnnotationSetNames():
 					menu.addAction(name, lambda name=name: self.loadAnnotations(name, self.selBuffer))
 				menu.addAction("New...", lambda: self.loadAnnotations(QInputDialog.getText(self, "Annotation Set", "Please enter a name for the new annotation set:")[0], self.selBuffer))
 
 			if self.formatInfoContainer:
-				menu = ctx.addMenu("Apply format info")
+				menu = ctx.addMenu("Parse Buffer")
 				for name in self.formatInfoContainer.definitions.keys():
 					menu.addAction(name, lambda name=name: self.applyFormatInfo(name, self.selBuffer))
 				#menu.addAction("New...", lambda: )
@@ -224,17 +214,17 @@ class HexView2(QWidget):
 		ctx.addAction("Paste", lambda: self.setBuffer(parseHexFromClipboard()))
 		menu = ctx.addMenu("Paste as")
 		menu.addAction("Base64", lambda: self.setBuffer(ByteBuffer(b64decode(getClipboardText()))))
-		ctx.addAction("Clear ranges", lambda: self.clearRanges())
+		ctx.addAction("Clear Annotations" + (" on All Buffers" if len(self.buffers) > 0 else ""), lambda: self.clearRanges())
 
 		if self.project:
-			menu = ctx.addMenu("Load annotation set" + (" on all buffers" if len(self.buffers) > 0 else ""))
+			menu = ctx.addMenu("Load Annotation Set" + (" on All Buffers" if len(self.buffers) > 0 else ""))
 			for name in self.project.getAnnotationSetNames():
 				menu.addAction(name, lambda name=name: self.loadAnnotations(name))
 			menu.addAction("New...", lambda: self.loadAnnotations(
 				QInputDialog.getText(self, "Annotation Set", "Please enter a name for the new annotation set:")[0]))
 
 		if self.formatInfoContainer:
-			menu = ctx.addMenu("Apply format info" + (" on all buffers" if len(self.buffers) > 0 else ""))
+			menu = ctx.addMenu("Parse" + (" All Buffers" if len(self.buffers) > 0 else " Buffer"))
 			for name in self.formatInfoContainer.definitions.keys():
 				menu.addAction(name, lambda name=name: self.applyFormatInfo(name))
 
@@ -262,7 +252,8 @@ class HexView2(QWidget):
 		self.project.storeAnnotation(self.annotationSetName, range)
 
 	def clearRanges(self):
-		self.buffers[0].clearRanges()
+		for buf in self.buffers:
+			buf.clearRanges()
 		self.redraw()
 
 	def getRangeString(self, range, style=(" ","%02X")):
@@ -321,23 +312,10 @@ class HexView2(QWidget):
 	def _formatInfoUpdated(self):
 		self.applyFormatInfo()
 
-	def _parseBuffer(self, buf):
-		if buf.fi_root_name is None: return
-		try:
-			# clear out the old ranges from the last run, but don't delete ranges from other sources (e.g. style, bidi-buf)
-			buf.setRanges(buf.matchRanges(doesntHaveMetaKey='_sdef_ref'))
-			parse_context = BytebufferAnnotatingParseContext(self.formatInfoContainer, buf)
-			parse_context.on_new_subflow_category = self._newSubflowCategory
-			buf.fi_tree = parse_context.parse(buf.fi_root_name)
-		except parse_exception as ex:
-			logging.exception("Failed to apply format info")
-			logging.getLogger("DataSource").error("Failed to apply format info: " + str(ex))
-
 	def applyFormatInfo(self, root_name=None, bufIdx=None):
 		for buf in self.buffers if bufIdx is None else [self.buffers[bufIdx]]:
 			if root_name is not None: buf.fi_root_name = root_name
-			self._parseBuffer(buf)
-		# QMessageBox.warning(self, "Failed to apply format info", str(ex))
+			apply_grammar_on_bbuf(buf, buf.fi_root_name, self._newSubflowCategory)
 		self.parseResultsUpdated.emit([buf.fi_tree for buf in self.buffers])
 		self.redraw()
 
@@ -551,7 +529,8 @@ class HexView2(QWidget):
 
 			if Qt.Key_A <= e.key() <= Qt.Key_Z:
 				letter = chr(e.key() - Qt.Key_A + 0x41)
-				info = next((x for x in HexView2.userStyles if x[0] == letter), None)
+				styles = guihelper.getHighlightStyles()
+				info = next((x for x in styles if x[0] == letter), None)
 				if info:
 					self.styleSelection(**info[2])
 
